import { OnInit } from '@angular/core';
import { Subject } from 'rxjs';
import { ThemeService } from '../theme.service';
import * as i0 from "@angular/core";
export declare enum Sizes {
    sm = "sm",
    md = "md",
    lg = "lg"
}
export declare enum Styles {
    icon = "icon",
    label = "label"
}
/**
 * A tri-state toggle button for switching between `light`, `auto` and `dark` theme.
 * Size and style (icon vs label) are configurable.
 */
export declare class ThemeSwitchComponent implements OnInit {
    private themeService;
    theme$: Subject<string | null>;
    /**
     * The size of the toggle button.
     *
     * - `sm` and `lg` translate to Bootstrap's `.btn-sm` and `.btn-lg`, respectively.
     * - `md` is the default and translates to just `.btn`.
     *
     * @see https://getbootstrap.com/docs/5.2/components/buttons/#sizes
     */
    size: Sizes | string | null | undefined;
    /**
     * The style of the button labels.
     *
     * - `icon` is the default and displays the Octicons for sun (light mode), telescope (auto mode) and moon (dark mode),
     * while also adding invisible text for screen readers.
     * - `label` uses textual labels instead (Light, Auto, Dark).
     *
     * @see https://primer.style/octicons/sun-16
     * @see https://primer.style/octicons/telescope-16
     * @see https://primer.style/octicons/moon-16
     */
    style: Styles | string | null | undefined;
    constructor(themeService: ThemeService);
    ngOnInit(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ThemeSwitchComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ThemeSwitchComponent, "olt-ngbd-theme-switch", never, { "size": { "alias": "size"; "required": false; }; "style": { "alias": "style"; "required": false; }; }, {}, never, never, false, never>;
}
