import { InjectionToken } from '@angular/core';
import { Observable, Subject } from 'rxjs';
import * as i0 from "@angular/core";
export type DetectedTheme = 'dark' | 'light';
export type ThemeLoader = () => Observable<string | null>;
export type ThemeSaver = (theme: string | null) => void;
/**
 * A function that loads the saved theme.
 * Defaults to loading from local storage with the key `theme`.
 */
export declare const THEME_LOADER: InjectionToken<ThemeLoader>;
/**
 * A function that saves the theme.
 * Defaults to saving to local storage with the key `theme`.
 */
export declare const THEME_SAVER: InjectionToken<ThemeSaver>;
export declare class ThemeService {
    private _theme;
    constructor(document: any, loadHandler: any, saveHandler: any);
    /**
     * @return a subject representing the currently active theme
     */
    get theme$(): Subject<string | null>;
    /**
     * @return `dark` if the user agent prefers dark color scheme, `light` otherwise
     */
    get detectedTheme(): DetectedTheme;
    /**
     * @return an observable version of {@link detectedTheme} that automatically updates on changes, e.g. when the user
     * changes their operating system theme preference, or it switches depending on day/night.
     */
    get detectedTheme$(): Observable<DetectedTheme>;
    /**
     * @return the current theme
     */
    get theme(): string | null;
    /**
     * @param value
     *  the new theme
     */
    set theme(value: string | null);
    static ɵfac: i0.ɵɵFactoryDeclaration<ThemeService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ThemeService>;
}
